@@ -31,9 +31,10 @@ Test.prototype = {
         var titles = {}, i;
         for (i = 0; i < log.length; i++) {
             if (log[i].func === 'Unity.MediaPlayer.setTrack') {
-              var title = log[i].args[0].title;
-              if (title && title.length !== 0)
-                titles[log[i].args[0].title] = 1;
+                var title = log[i].args[0].title;
+                if (title && title.length !== 0) {
+                    titles[log[i].args[0].title] = 1;
+                }
             }
         }
 
